const id = "IG_EVENT_RGB_SET";
const groups = ["RGB LED (iG)"];
const name = "Set RGB LED";

const timeField = (
  label,
  variableFieldKey,
  valueFieldKey,
  typeFieldKey,
  min,
  max
) => {
  return {
    type: "group",
    width: "50%",
    fields: [
      {
        key: variableFieldKey,
        label: label,
        type: "variable",
        defaultValue: "LAST_VARIABLE",
        conditions: [
          {
            key: typeFieldKey,
            eq: "variable",
          },
        ],
      },
      {
        key: valueFieldKey,
        label: label,
        type: "number",
        defaultValue: 0,
        min: min,
        max: max,
        conditions: [
          {
            key: typeFieldKey,
            eq: "number",
          },
        ],
      },
      {
        key: typeFieldKey,
        type: "selectbutton",
        options: [
          ["variable", "variable"],
          ["number", "number"],
        ],
        inline: true,
        defaultValue: "number",
      },
    ],
  };
};

const fields = [
  timeField("Red", "variableRed", "valueRed", "typeRed", 0, 255),
  timeField("Green", "variableGreen", "valueGreen", "typeGreen", 0, 255),
  timeField("Blue", "variableBlue", "valueBlue", "typeBlue", 0, 255),
];

const compile = (input, helpers) => {
  const {
    appendRaw,
    getVariableAlias,
    _isArg,
    _stackPushConst,
    _addComment,
    _stackPop,
    _stackPush,
    _stackPushInd,
    _stackOffset,
  } = helpers;

  const {
    variableRed,
    variableGreen,
    variableBlue,
    variableSeconds,
    valueRed,
    valueGreen,
    valueBlue,
    valueSeconds,
    typeRed,
    typeGreen,
    typeBlue,
    typeSeconds,
  } = input;

  const RedVariableAlias = getVariableAlias(variableRed);
  const GreenVariableAlias = getVariableAlias(variableGreen);
  const BlueVariableAlias = getVariableAlias(variableBlue);

  _addComment("RGB LED: Set Colour");

  if (typeRed === "number") {
	 //_stackPushConst(valueRed, "Red");
	 appendRaw(`vm_set_const_int8	0x6000, 0x08`);
	 appendRaw(`vm_set_const_int8	0x6000, 0x00`);
	 
	 for (let temp = 7; temp >= 0; temp--) {
		if (valueRed & (1<<temp)) {
			appendRaw(`vm_set_const_int8	0x6000, 0x06`);
		}
		else {
			appendRaw(`vm_set_const_int8	0x6000, 0x02`);
		}
		appendRaw(`vm_set_const_int8	0x6000, 0x00`);
	 }
  }
  
  
  if (typeGreen === "number") {
   // _stackPushConst(valueGreen, "Green");
	for (let temp = 7; temp >= 0; temp--) {
		if (valueGreen & (1<<temp)) {
			appendRaw(`vm_set_const_int8	0x6000, 0x06`);
		}
		else {
			appendRaw(`vm_set_const_int8	0x6000, 0x02`);
		}
		appendRaw(`vm_set_const_int8	0x6000, 0x00`);
	 }
  } 
  
  if (typeBlue === "number") {
    //_stackPushConst(valueBlue, "Blue");
	 for (let temp = 7; temp >= 0; temp--) {
		if (valueBlue & (1<<temp)) {
			appendRaw(`vm_set_const_int8	0x6000, 0x06`);
		}
		else {
			appendRaw(`vm_set_const_int8	0x6000, 0x02`);
		}
		appendRaw(`vm_set_const_int8	0x6000, 0x00`);
	 }
	 
	 appendRaw(`vm_set_const_int8	0x6000, 0x08`);
  }

  

  
};

module.exports = {
  id,
  name,
  groups,
  fields,
  compile,
};
